summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/backends/qgpgme/qgpgmecryptoconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/lib/backends/qgpgme/qgpgmecryptoconfig.cpp')
-rw-r--r--certmanager/lib/backends/qgpgme/qgpgmecryptoconfig.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/certmanager/lib/backends/qgpgme/qgpgmecryptoconfig.cpp b/certmanager/lib/backends/qgpgme/qgpgmecryptoconfig.cpp
index 2b81c6b1a..c77dcb208 100644
--- a/certmanager/lib/backends/qgpgme/qgpgmecryptoconfig.cpp
+++ b/certmanager/lib/backends/qgpgme/qgpgmecryptoconfig.cpp
@@ -32,7 +32,7 @@
#include "qgpgmecryptoconfig.h"
#include <kdebug.h>
-#include <kprocio.h>
+#include <tdeprocio.h>
#include <errno.h>
#include <tdemessagebox.h>
#include <tdelocale.h>
@@ -71,12 +71,12 @@ void QGpgMECryptoConfig::runGpgConf( bool showErrors )
{
// Run gpgconf --list-components to make the list of components
- KProcIO proc( TQTextCodec::codecForName( "utf8" ) );
+ TDEProcIO proc( TQTextCodec::codecForName( "utf8" ) );
proc << "gpgconf"; // must be in the PATH
proc << "--list-components";
- TQObject::connect( &proc, TQ_SIGNAL( readReady(KProcIO*) ),
- this, TQ_SLOT( slotCollectStdOut(KProcIO*) ) );
+ TQObject::connect( &proc, TQ_SIGNAL( readReady(TDEProcIO*) ),
+ this, TQ_SLOT( slotCollectStdOut(TDEProcIO*) ) );
// run the process:
int rc = 0;
@@ -100,7 +100,7 @@ void QGpgMECryptoConfig::runGpgConf( bool showErrors )
mParsed = true;
}
-void QGpgMECryptoConfig::slotCollectStdOut( KProcIO* proc )
+void QGpgMECryptoConfig::slotCollectStdOut( TDEProcIO* proc )
{
TQString line;
int result;
@@ -166,15 +166,15 @@ void QGpgMECryptoConfigComponent::runGpgConf()
{
// Run gpgconf --list-options <component>, and create all groups and entries for that component
- KProcIO proc( TQTextCodec::codecForName( "utf8" ) );
+ TDEProcIO proc( TQTextCodec::codecForName( "utf8" ) );
proc << "gpgconf"; // must be in the PATH
proc << "--list-options";
proc << mName;
//kdDebug(5150) << "Running gpgconf --list-options " << mName << endl;
- TQObject::connect( &proc, TQ_SIGNAL( readReady(KProcIO*) ),
- this, TQ_SLOT( slotCollectStdOut(KProcIO*) ) );
+ TQObject::connect( &proc, TQ_SIGNAL( readReady(TDEProcIO*) ),
+ this, TQ_SLOT( slotCollectStdOut(TDEProcIO*) ) );
mCurrentGroup = 0;
// run the process:
@@ -192,7 +192,7 @@ void QGpgMECryptoConfigComponent::runGpgConf()
}
}
-void QGpgMECryptoConfigComponent::slotCollectStdOut( KProcIO* proc )
+void QGpgMECryptoConfigComponent::slotCollectStdOut( TDEProcIO* proc )
{
TQString line;
int result;
@@ -265,7 +265,7 @@ void QGpgMECryptoConfigComponent::sync( bool runtime )
line += ":16:";
}
line += '\n';
- TQCString line8bit = line.utf8(); // encode with utf8, and KProcIO uses utf8 when reading.
+ TQCString line8bit = line.utf8(); // encode with utf8, and TDEProcIO uses utf8 when reading.
tmpFile.file()->writeBlock( line8bit.data(), line8bit.size()-1 /*no 0*/ );
dirtyEntries.append( it.current() );
}